@@ -52,6 +52,16 @@ def projects_api_get_project_statuses_call(return_value, raised=None):
     return create_mock_call(method_name, return_value, side_effect=raised)
 
 
+def projects_api_get_project_types_call(return_value, raised=None):
+    method_name = 'djconnectwise.api.ProjectAPIClient.get_project_types'
+    return create_mock_call(method_name, return_value, side_effect=raised)
+
+
+def projects_api_get_project_phases_call(return_value, raised=None):
+    method_name = 'djconnectwise.api.ProjectAPIClient.get_project_phases'
+    return create_mock_call(method_name, return_value, side_effect=raised)
+
+
 def project_api_get_projects_call(return_value):
     method_name = 'djconnectwise.api.ProjectAPIClient.get_projects'
     return create_mock_call(method_name, return_value)
@@ -62,6 +72,35 @@ def project_api_get_project_call(return_value, raised=None):
     return create_mock_call(method_name, return_value, side_effect=raised)
 
 
+def _project_api_tickets_call(page=1, page_size=25, conditions=[]):
+    return_value = []
+    test_date = date(1948, 5, 14)
+    test_time = time(12, 0, 0, tzinfo=timezone.get_current_timezone())
+    test_datetime = datetime.combine(test_date, test_time)
+    conditions.append('lastUpdated>' + timezone.localtime(
+        value=test_datetime).isoformat()
+                      )
+    if page == 1:
+        return_value = [fixtures.API_PROJECT_TICKET]
+
+    return return_value
+
+
+def project_api_tickets_call():
+    method_name = 'djconnectwise.api.TicketAPIMixin.get_tickets'
+    mock_call, _patch = create_mock_call(
+        method_name,
+        None,
+        side_effect=_project_api_tickets_call)
+    return mock_call, _patch
+
+
+def project_api_tickets_test_command(return_value):
+    method_name = 'djconnectwise.api.TicketAPIMixin.get_tickets'
+    mock_call, _patch = create_mock_call(method_name, return_value)
+    return mock_call, _patch
+
+
 def sales_api_by_id_call(return_value, raised=None):
     method_name = 'djconnectwise.api.SalesAPIClient.by_id'
     return create_mock_call(method_name, return_value, side_effect=raised)
@@ -77,13 +116,13 @@ def sales_api_get_opportunity_statuses_call(return_value, raised=None):
     return create_mock_call(method_name, return_value, side_effect=raised)
 
 
-def sales_api_get_opportunity_stages_call(return_value, raised=None):
-    method_name = 'djconnectwise.api.SalesAPIClient.get_opportunity_stages'
+def sales_api_get_opportunity_types_call(return_value, raised=None):
+    method_name = 'djconnectwise.api.SalesAPIClient.get_opportunity_types'
     return create_mock_call(method_name, return_value, side_effect=raised)
 
 
-def sales_api_get_opportunity_types_call(return_value, raised=None):
-    method_name = 'djconnectwise.api.SalesAPIClient.get_opportunity_types'
+def sales_api_get_opportunity_stages_call(return_value, raised=None):
+    method_name = 'djconnectwise.api.SalesAPIClient.get_opportunity_stages'
     return create_mock_call(method_name, return_value, side_effect=raised)
 
 
@@ -137,6 +176,16 @@ def sales_api_get_activities_call(return_value, raised=None):
     return create_mock_call(method_name, return_value, side_effect=raised)
 
 
+def sales_api_get_activities_statuses_call(return_value, raised=None):
+    method_name = 'djconnectwise.api.SalesAPIClient.get_activity_statuses'
+    return create_mock_call(method_name, return_value, side_effect=raised)
+
+
+def sales_api_get_activities_types_call(return_value, raised=None):
+    method_name = 'djconnectwise.api.SalesAPIClient.get_activity_types'
+    return create_mock_call(method_name, return_value, side_effect=raised)
+
+
 def sales_api_get_single_activity_call(return_value, raised=None):
     method_name = 'djconnectwise.api.SalesAPIClient.get_single_activity'
     return create_mock_call(method_name, return_value, side_effect=raised)
@@ -156,7 +205,7 @@ def _service_api_tickets_call(page=1, page_size=25, conditions=[]):
 
 
 def service_api_tickets_call():
-    method_name = 'djconnectwise.api.ServiceAPIClient.get_tickets'
+    method_name = 'djconnectwise.api.TicketAPIMixin.get_tickets'
     mock_call, _patch = create_mock_call(
         method_name,
         None,
@@ -169,7 +218,7 @@ def _service_api_get_ticket_call(ticket_id):
 
 
 def service_api_get_ticket_call(raised=None):
-    method_name = 'djconnectwise.api.ServiceAPIClient.get_ticket'
+    method_name = 'djconnectwise.api.TicketAPIMixin.get_ticket'
     mock_call, _patch = create_mock_call(
         method_name,
         None,
@@ -299,6 +348,21 @@ def get(url, data, headers=None, status=200):
     get_raw(url, json.dumps(data), "application/json", headers, status=status)
 
 
+def time_api_get_work_types_call(return_value):
+    method_name = 'djconnectwise.api.TimeAPIClient.get_work_types'
+    return create_mock_call(method_name, return_value)
+
+
+def time_api_get_work_roles_call(return_value):
+    method_name = 'djconnectwise.api.TimeAPIClient.get_work_roles'
+    return create_mock_call(method_name, return_value)
+
+
+def finance_api_get_agreements_call(return_value):
+    method_name = 'djconnectwise.api.FinanceAPIClient.get_agreements'
+    return create_mock_call(method_name, return_value)
+
+
 def get_raw(url, data, content_type="application/octet-stream", headers=None,
             status=200):
     """Set up requests mock for given URL."""
